@@ -8,7 +8,18 @@ from .result import Error
 import datetime
 
 class ApiEncoder(JSONEncoder):
+    _encoders = []
+
     def default(self, obj):
+        for encoder in self._encoders:
+            try:
+                result = encoder.default(obj)
+
+                if result is not None:
+                    return self.default(result)
+            except Exception:
+                pass
+
         if isinstance(obj, Model):
             return self.default({i.name: getattr(obj, i.name) for i in obj.__table__.columns})
         elif isinstance(obj, AbstractKeyedTuple):
@@ -34,3 +45,11 @@ class ApiEncoder(JSONEncoder):
             return str(obj)
         else:
             return obj
+            
+    @classmethod
+    def add_encoder(cls, encoder):
+        cls._encoders.append(encoder)
+
+    @classmethod
+    def remove_encoder(cls, encoder):
+        cls._encoders.remove(encoder)
\ No newline at end of file
