@@ -1,10 +1,10 @@
 from werkzeug.exceptions import HTTPException
 from sqlalchemy.exc import SQLAlchemyError
-from result import Result
-from constant import Error
-from import exception
 from flask import current_app as app
 from json import JSONDecodeError
+from .result import Result
+from .constant import Error
+from . import exception
 
 def _handle_error(e):
     if isinstance(e, HTTPException):
